#!/usr/bin/env python

# Copyright and license: Please refer to LICENSE.TXT

import sys
import os
import re
import os.path

_selfpath=(os.path.dirname(os.path.realpath(__file__)).split('/'))[:-2]
_selfpath.append('pylibs')
_libspath='/'.join(_selfpath)
sys.path.append(_libspath)

from s2p import *

sys.path.append(CORE_PATH_SDK+'/python')

from s2p_base import *
from s2p_logger import *

S2P_CONF_SYSTEM		= xml_to_array(CORE_PATH_CONFIG+'/system.xml')

if os.path.isfile(CORE_PATH_CONFIG+'/drivers/diva.xml'):
	DRIVER_CONF = xml_to_array(CORE_PATH_CONFIG+'/drivers/diva.xml', 0)

else:
	s2p_log("configure.diva", "warn", "Missing configuration file, setting default values")
	
	DRIVER_CONF={
		'devices': { 0: { '+': {
		
		} } }
	}

# Remove OS drivers
if not os.path.isfile("/usr/lib/divas/divas_cfg.rc"):
	os.system("rmmod divas")
	os.system("rmmod divadidd")
	sys.exit(0)

if not os.path.isdir("/usr/lib/divas"):
	s2p_log("configure.diva", "error", "Missing OS drivers under /usr/lib/divas")
	sys.exit(-1)

# Run diva configure twice
os.system("/usr/lib/divas/divas_cfg.rc")
os.system("/usr/lib/divas/divas_cfg.rc")

if not os.path.isdir('/proc/net/eicon'): sys.exit(0)

def configure_adapter(info, n):
	default_conf={
		'id'				: info['Serial'],
		'composing-timeout'	: 2,
		'echo-cancel'		: 'true'
	}

	if not DRIVER_CONF['devices'][0]['+'].has_key('item') or not DRIVER_CONF['devices'][0]['+']['item'].has_key(n):
		s2p_log("configure.diva", "info", "Detected new Diva adapter '"+info['Name']+"', setting to default values")
		dev_conf=default_conf
		
	else:
		dev_conf_tmp=xml_simplify_array(DRIVER_CONF['devices'][0]['+']['item'][n])

		if dev_conf_tmp['id'] != info['Serial']:
			s2p_log("configure.diva", "warn", "Serial mismatch for '"+info['Name']+"', did you change hardware config?")
			s2p_log("configure.diva", "warn", "Recovering '"+info['Name']+"', to default values")

			dev_conf=default_conf
		else:
			s2p_log("configure.diva", "info", "Detected an already existing card '"+info['Name']+"'")
			dev_conf=dev_conf_tmp

	out ="<item>\n"

	for k in dev_conf.keys():
		if k == {}:	out+="<"+k+" />\n"
		else:		out+="<"+k+">"+str(dev_conf[k])+"</"+k+">\n"

	out+="</item>\n"

	return out

xml_devices=""
device_n=0

while True:
	device_n=device_n+1
	info={}

	if not os.path.isdir('/proc/net/eicon/adapter'+str(device_n)): break
	fp=open('/proc/net/eicon/adapter'+str(device_n)+'/info', 'r')

	info={}
	while True:
		line=fp.readline()
		if not line: break
		
		couple=re.split(r'\s+:\s+', re.sub(r'[\n\r]+', '', line), 2)
		info[couple[0]]=couple[1]

	fp.close()

	xml_devices+=configure_adapter(info, device_n-1)

fp=open(CORE_PATH_CONFIG+'/drivers/diva.xml', 'w')
fp.write('<?xml version="1.0" encoding="utf-8"?>'+"\n")
fp.write("<config>\n")
fp.write("<devices>\n")
fp.write(xml_devices)
fp.write("</devices>\n")
fp.write("</config>\n")
fp.close()

os.system("chmod 666 /dev/capi20")
os.system("chmod 666 /dev/Diva*")

