#!/usr/bin/env python

# Copyright and license: Please refer to LICENSE.TXT

import sys
import os
import os.path
import string
import re
import time
import signal
import thread
from xml.sax import saxutils
from threading import Lock

_selfpath=(os.path.dirname(os.path.realpath(__file__)).split('/'))[:-1]
_selfpath.append('pylibs')
_libspath='/'.join(_selfpath)
sys.path.append(_libspath)

from s2p import *
from s2p_logger import *
from s2p_usock import *

S2P_CONF_SYSTEM = xml_to_array(CORE_PATH_CONFIG+'/system.xml')

INTERVAL = 10
resources={}

##########################################################################################
# Misc functions

def gettime_list():
	stat_file = file("/proc/stat", "r")
	time_list = stat_file.readline().split(" ")[2:6]
	stat_file.close()

	for i in range(len(time_list))  :
		time_list[i] = int(time_list[i])

	return time_list

def data_time(interval):
	x = gettime_list()
	time.sleep(interval)
	y = gettime_list()

	for i in range(len(x)): y[i] -= x[i]

	return y

##########################################################################################
# Signal handler

def sighandler_quit(signum, frame):
	s2p_log("resources", "info", "Resources monitor stopped due to signal "+str(signum))
	s2p_deregister_pid('resources_monitor')
	sys.exit(0)

##########################################################################################
# Server

def manage_server(mysock):
	while True:
		thread.start_new_thread(manage_server_connection, (mysock.accept(),))

def manage_server_connection(mysock):
	global resources

	mysock.start()

	while mysock.is_connected():
		if mysock.wait_for_incoming():
			mysock.read()

			for k in resources.keys():
				mysock.send(k+":"+str(resources[k]))

			mysock.send(".")

	mysock.close()

##########################################################################################
# Socket cleaning

pid=s2p_register_pid('resources_monitor')
s2p_log("resources", "info", "Resources monitor started with pid "+str(pid))

sock_file=S2P_CONF_SYSTEM['path']['socks']+'/resources-monitor.sock'

try:
	os.unlink(sock_file)
except:
	1

# Start listening
sock_link=s2p_usock()
sock_link.bind(sock_file, 120)
sock_link.set_xml_mode(False)
os.chmod(sock_file, 0777)

# Start connections threads
thread.start_new_thread(manage_server, (sock_link,))	# From Skype

signal.signal(signal.SIGHUP, sighandler_quit)
signal.signal(signal.SIGINT, sighandler_quit)
signal.signal(signal.SIGQUIT, sighandler_quit)
signal.signal(signal.SIGTERM, sighandler_quit)

while True:
	dt = data_time(INTERVAL)
	cpu_pct = 100 - (dt[len(dt) - 1] * 100.00 / sum(dt))
	resources['cpuload']=cpu_pct
	